Rotating point source
=====================
This example demonstrates a simple approach to beamforming on a rotating source. 

Download: :download:`example_rotating_point_source.py <../../../examples/example_rotating_point_source.py>`

The script produces three figures:

.. list-table::
    :widths: 25 25 50
    
    * - .. figure:: example_rotating_point_source_1.png
            :align: center
	    :width: 100%
	    :figwidth: 80%

            Results for a time domain beamformer with fixed focus
  
      - .. figure:: example_rotating_point_source_2.png
            :align: center
	    :width: 100%
	    :figwidth: 80%

            Results for a time domain beamformer with focus moving along a circle trajectory

      - .. figure:: example_rotating_point_source_3.png
            :align: center
	    :width: 100%
	    :figwidth: 80%

            Time-averaged results for different beamformers


.. literalinclude:: ../../../examples/example_rotating_point_source.py
